# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"load_data": "00_utils.ipynb",
         "kaggle_submit_command": "00_utils.ipynb",
         "average_preds": "00_utils.ipynb",
         "get_averaged_preds": "00_utils.ipynb",
         "get_datablock": "01_dataset.ipynb",
         "get_dls": "01_dataset.ipynb",
         "get_dls_all_in_1": "01_dataset.ipynb",
         "infer_on_test_set": "02_evaluate.ipynb",
         "format_submission": "02_evaluate.ipynb",
         "evaluate": "02_evaluate.ipynb",
         "timm_or_fastai_arch": "03_train.ipynb",
         "train": "03_train.ipynb",
         "softmax_RocAuc": "03_train.ipynb",
         "train_cv": "03_train.ipynb",
         "generate_pseudo_labels": "04_generate_pseudo_labels.ipynb",
         "create_folds": "06_create_folds.ipynb",
         "MODELS": "07_pretrained_models.ipynb",
         "get_model": "07_pretrained_models.ipynb",
         "DATA_PATH": "config.ipynb",
         "TEST_DATA_PATH": "config.ipynb"}

modules = ["utils.py",
           "dataset.py",
           "evaluate.py",
           "train.py",
           "generate_pseudo_labels.py",
           "self_knowledge_distillation.py",
           "create_folds.py",
           "pretrained_models.py",
           "config.py"]

doc_url = "https://bwolfson97.github.io/plant_pathology/"

git_url = "https://github.com/bwolfson97/plant_pathology/tree/master/"

def custom_doc_links(name): return None
