# AUTOGENERATED! DO NOT EDIT! File to edit: nbks/config.ipynb (unless otherwise specified).

__all__ = ['DATA_PATH', 'TEST_DATA_PATH']

# Cell
from pathlib import Path

# Cell
# Change to reflect your machine
DATA_PATH = Path("../data/")
TEST_DATA_PATH = Path("../test_data/")